@@ -10,12 +10,13 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -42,7 +43,6 @@ __all__ = (
     "EC2SpecificationTypeDef",
     "ESInstanceDetailsTypeDef",
     "ElastiCacheInstanceDetailsTypeDef",
-    "ExpressionTypeDef",
     "ForecastResultTypeDef",
     "GroupDefinitionTypeDef",
     "GroupTypeDef",
@@ -86,6 +86,7 @@ __all__ = (
     "CreateCostCategoryDefinitionResponseTypeDef",
     "DeleteCostCategoryDefinitionResponseTypeDef",
     "DescribeCostCategoryDefinitionResponseTypeDef",
+    "ExpressionTypeDef",
     "GetCostAndUsageResponseTypeDef",
     "GetCostAndUsageWithResourcesResponseTypeDef",
     "GetCostForecastResponseTypeDef",
@@ -117,7 +118,7 @@ CostCategoryReferenceTypeDef = TypedDict(
 )
 
 CostCategoryRuleTypeDef = TypedDict(
-    "CostCategoryRuleTypeDef", {"Value": str, "Rule": "ExpressionTypeDef"}
+    "CostCategoryRuleTypeDef", {"Value": str, "Rule": Dict[str, Any]}
 )
 
 _RequiredCostCategoryTypeDef = TypedDict(
@@ -331,19 +332,6 @@ ElastiCacheInstanceDetailsTypeDef = TypedDict(
     total=False,
 )
 
-ExpressionTypeDef = TypedDict(
-    "ExpressionTypeDef",
-    {
-        "Or": List["ExpressionTypeDef"],
-        "And": List["ExpressionTypeDef"],
-        "Not": "ExpressionTypeDef",
-        "Dimensions": "DimensionValuesTypeDef",
-        "Tags": "TagValuesTypeDef",
-        "CostCategories": "CostCategoryValuesTypeDef",
-    },
-    total=False,
-)
-
 ForecastResultTypeDef = TypedDict(
     "ForecastResultTypeDef",
     {
@@ -821,6 +809,19 @@ DescribeCostCategoryDefinitionResponseTypeDef = TypedDict(
     total=False,
 )
 
+ExpressionTypeDef = TypedDict(
+    "ExpressionTypeDef",
+    {
+        "Or": List[Dict[str, Any]],
+        "And": List[Dict[str, Any]],
+        "Not": Dict[str, Any],
+        "Dimensions": "DimensionValuesTypeDef",
+        "Tags": "TagValuesTypeDef",
+        "CostCategories": "CostCategoryValuesTypeDef",
+    },
+    total=False,
+)
+
 GetCostAndUsageResponseTypeDef = TypedDict(
     "GetCostAndUsageResponseTypeDef",
     {
